@@ -3,6 +3,7 @@
 
 namespace Icinga\Forms;
 
+use Icinga\Application\Hook\ConfigFormEventsHook;
 use Icinga\Web\Form;
 
 class ActionForm extends Form
@@ -58,4 +59,20 @@ class ActionForm extends Form
             ]
         );
     }
+
+    public function isValid($formData)
+    {
+        $valid = parent::isValid($formData);
+
+        if ($valid) {
+            $valid = ConfigFormEventsHook::runIsValid($this);
+        }
+
+        return $valid;
+    }
+
+    public function onSuccess()
+    {
+        ConfigFormEventsHook::runOnSuccess($this);
+    }
 }
