@@ -6,6 +6,8 @@ namespace Icinga\Forms;
 use Exception;
 use Zend_Form_Decorator_Abstract;
 use Icinga\Application\Config;
+use Icinga\Application\Hook\ConfigFormEventsHook;
+use Icinga\Exception\ConfigurationError;
 use Icinga\Web\Form;
 use Icinga\Web\Notification;
 
@@ -51,23 +53,35 @@ class ConfigForm extends Form
         return $this;
     }
 
-    /**
-     * {@inheritdoc}
-     */
+    public function isValid($formData)
+    {
+        $valid = parent::isValid($formData);
+
+        if ($valid && ConfigFormEventsHook::runIsValid($this) === false) {
+            foreach (ConfigFormEventsHook::getLastErrors() as $msg) {
+                $this->error($msg);
+            }
+
+            $valid = false;
+        }
+
+        return $valid;
+    }
+
     public function onSuccess()
     {
         $sections = array();
-        foreach ($this->getValues() as $sectionAndPropertyName => $value) {
-            if ($value === '') {
-                $value = null; // Causes the config writer to unset it
-            }
-
+        foreach (static::transformEmptyValuesToNull($this->getValues()) as $sectionAndPropertyName => $value) {
             list($section, $property) = explode('_', $sectionAndPropertyName, 2);
             $sections[$section][$property] = $value;
         }
 
         foreach ($sections as $section => $config) {
-            $this->config->setSection($section, $config);
+            if ($this->isEmptyConfig($config)) {
+                $this->config->removeSection($section);
+            } else {
+                $this->config->setSection($section, $config);
+            }
         }
 
         if ($this->save()) {
@@ -75,11 +89,15 @@ class ConfigForm extends Form
         } else {
             return false;
         }
+
+        if (ConfigFormEventsHook::runOnSuccess($this) === false) {
+            Notification::error($this->translate(
+                'Configuration successfully stored. Though, one or more module hooks failed to run.'
+                . ' See logs for details'
+            ));
+        }
     }
 
-    /**
-     * {@inheritdoc}
-     */
     public function onRequest()
     {
         $values = array();
@@ -103,6 +121,10 @@ class ConfigForm extends Form
     {
         try {
             $this->writeConfig($this->config);
+        } catch (ConfigurationError $e) {
+            $this->addError($e->getMessage());
+
+            return false;
         } catch (Exception $e) {
             $this->addDecorator('ViewScript', array(
                 'viewModule'    => 'default',
@@ -127,4 +149,44 @@ class ConfigForm extends Form
     {
         $config->saveIni();
     }
+
+    /**
+     * Get whether the given config is empty or has only empty values
+     *
+     * @param array|Config $config
+     *
+     * @return bool
+     */
+    protected function isEmptyConfig($config)
+    {
+        if ($config instanceof Config) {
+            $config = $config->toArray();
+        }
+
+        foreach ($config as $value) {
+            if ($value !== null) {
+                return false;
+            }
+        }
+
+        return true;
+    }
+
+    /**
+     * Transform all empty values of the given array to null
+     *
+     * @param   array   $values
+     *
+     * @return  array
+     */
+    public static function transformEmptyValuesToNull(array $values)
+    {
+        array_walk($values, function (&$v) {
+            if ($v === '' || $v === false || $v === array()) {
+                $v = null;
+            }
+        });
+
+        return $values;
+    }
 }
