@@ -427,6 +427,9 @@ abstract class ApplicationBootstrap
         $paths = [];
 
         $configured = getenv('ICINGAWEB_MODULES_DIR');
+        if (! $configured && is_dir($this->baseDir . '/modules')) {
+            $configured = $this->baseDir . '/modules';
+        }
         if (! $configured) {
             $configured = $this->config->get('global', 'module_path', $this->baseDir . '/modules');
         }
@@ -568,7 +571,7 @@ abstract class ApplicationBootstrap
      */
     protected function setupErrorHandling()
     {
-        error_reporting(E_ALL | E_STRICT);
+        error_reporting(getenv('ICINGAWEB_ENVIRONMENT') === 'dev' ? E_ALL : E_ALL & ~E_DEPRECATED & ~E_USER_DEPRECATED);
         ini_set('display_startup_errors', 1);
         ini_set('display_errors', 1);
         set_error_handler(function ($errno, $errstr, $errfile, $errline) {
@@ -579,7 +582,6 @@ abstract class ApplicationBootstrap
             switch ($errno) {
                 case E_NOTICE:
                 case E_WARNING:
-                case E_STRICT:
                 case E_RECOVERABLE_ERROR:
                     throw new ErrorException($errstr, 0, $errno, $errfile, $errline);
             }
