@@ -76,6 +76,13 @@ class Module
      */
     private $libdir;
 
+    /**
+     * Config directory
+     *
+     * @var string
+     */
+    private $configdir;
+
     /**
      * Directory containing translations
      *
@@ -1036,7 +1043,7 @@ class Module
     public function providesSetupWizard()
     {
         $this->launchConfigScript();
-        if (class_exists($this->setupWizard)) {
+        if ($this->setupWizard && class_exists($this->setupWizard)) {
             $wizard = new $this->setupWizard;
             return $wizard instanceof SetupWizard;
         }
@@ -1308,7 +1315,7 @@ class Module
         $router = $this->app->getFrontController()->getRouter();
 
         // TODO: We should not be required to do this. Please check dispatch()
-        $this->app->getfrontController()->addControllerDirectory(
+        $this->app->getFrontController()->addControllerDirectory(
             $this->getControllerDir(),
             $this->getName()
         );
@@ -1388,22 +1395,6 @@ class Module
         return $this->includeScript($this->configScript);
     }
 
-    /**
-     * Register a hook
-     *
-     * @param   string  $name   Name of the hook
-     * @param   string  $class  Class of the hook w/ namespace
-     * @param   string  $key
-     *
-     * @return  $this
-     *
-     * @deprecated              Deprecated since 2.1.1. Use {@link provideHook()} instead
-     */
-    protected function registerHook($name, $class, $key = null)
-    {
-        return $this->provideHook($name, $class, $key);
-    }
-
     protected function slashesToNamespace($class)
     {
         $list = explode('/', $class);
