@@ -13,6 +13,7 @@ use Icinga\Data\Inspection;
 use Icinga\Exception\AuthenticationException;
 use Icinga\Exception\ConfigurationError;
 use Icinga\Exception\ProgrammingError;
+use Icinga\Exception\QueryException;
 use Icinga\Protocol\Ldap\LdapException;
 use Icinga\Protocol\Ldap\LdapUtils;
 use Icinga\Repository\LdapRepository;
@@ -169,7 +170,7 @@ class LdapUserGroupBackend extends LdapRepository implements Inspectable, UserGr
      */
     public function setUserBaseDn($baseDn)
     {
-        if (($baseDn = trim($baseDn))) {
+        if ($baseDn && ($baseDn = trim($baseDn))) {
             $this->userBaseDn = $baseDn;
         }
 
@@ -195,7 +196,7 @@ class LdapUserGroupBackend extends LdapRepository implements Inspectable, UserGr
      */
     public function setGroupBaseDn($baseDn)
     {
-        if (($baseDn = trim($baseDn))) {
+        if ($baseDn && ($baseDn = trim($baseDn))) {
             $this->groupBaseDn = $baseDn;
         }
 
@@ -336,7 +337,7 @@ class LdapUserGroupBackend extends LdapRepository implements Inspectable, UserGr
      */
     public function setUserFilter($filter)
     {
-        if (($filter = trim($filter))) {
+        if ($filter && ($filter = trim($filter))) {
             if ($filter[0] === '(') {
                 $filter = substr($filter, 1, -1);
             }
@@ -366,7 +367,7 @@ class LdapUserGroupBackend extends LdapRepository implements Inspectable, UserGr
      */
     public function setGroupFilter($filter)
     {
-        if (($filter = trim($filter))) {
+        if ($filter && ($filter = trim($filter))) {
             $this->groupFilter = $filter;
         }
 
@@ -431,9 +432,7 @@ class LdapUserGroupBackend extends LdapRepository implements Inspectable, UserGr
      */
     public function setDomain($domain)
     {
-        $domain = trim($domain);
-
-        if (strlen($domain)) {
+        if ($domain && ($domain = trim($domain))) {
             $this->domain = $domain;
         }
 
@@ -647,7 +646,7 @@ class LdapUserGroupBackend extends LdapRepository implements Inspectable, UserGr
      *
      * @param   string  $username
      *
-     * @param   string
+     * @return  string
      */
     protected function retrieveUserName($dn)
     {
