@@ -1,5 +1,5 @@
 <?php
-/* Icinga Web 2 | (c) 2013-2015 Icinga Development Team | GPLv2+ */
+/* Icinga Web 2 | (c) 2015 Icinga Development Team | GPLv2+ */
 
 namespace Icinga\Data\Tree;
 
@@ -14,7 +14,7 @@ class TreeNodeIterator implements RecursiveIterator
     /**
      * The node's children
      *
-     * @var array
+     * @var ArrayIterator
      */
     protected $children;
 
@@ -28,59 +28,37 @@ class TreeNodeIterator implements RecursiveIterator
         $this->children = new ArrayIterator($node->getChildren());
     }
 
-    /**
-     * {@inheritdoc}
-     */
-    public function current()
+    public function current(): TreeNode
     {
         return $this->children->current();
     }
 
-    /**
-     * {@inheritdoc}
-     */
-    public function key()
+    public function key(): int
     {
         return $this->children->key();
     }
 
-    /**
-     * {@inheritdoc}
-     */
-    public function next()
+    public function next(): void
     {
         $this->children->next();
     }
 
-    /**
-     * {@inheritdoc}
-     */
-    public function rewind()
+    public function rewind(): void
     {
         $this->children->rewind();
     }
 
-    /**
-     * {@inheritdoc}
-     */
-    public function valid()
+    public function valid(): bool
     {
         return $this->children->valid();
     }
 
-    /**
-     * {@inheritdoc}
-     */
-    public function hasChildren()
+    public function hasChildren(): bool
     {
         return $this->current()->hasChildren();
     }
 
-    /**
-     * {@inheritdoc}
-     * @return TreeNodeIterator
-     */
-    public function getChildren()
+    public function getChildren(): TreeNodeIterator
     {
         return new static($this->current());
     }
@@ -92,6 +70,6 @@ class TreeNodeIterator implements RecursiveIterator
      */
     public function isEmpty()
     {
-        return empty($this->children);
+        return ! $this->children->count();
     }
 }
