@@ -89,8 +89,6 @@ class LdapConnection implements Selectable, Inspectable
 
     /**
      * The LDAP link identifier being used
-     *
-     * @var resource
      */
     protected $ds;
 
@@ -248,7 +246,7 @@ class LdapConnection implements Selectable, Inspectable
      *
      * Establishes a connection if necessary.
      *
-     * @return  resource
+     * @throws LdapException
      */
     public function getConnection()
     {
@@ -617,9 +615,11 @@ class LdapConnection implements Selectable, Inspectable
     /**
      * Return whether an entry identified by the given distinguished name exists
      *
-     * @param   string  $dn
+     * @param string $dn
      *
      * @return  bool
+     *
+     * @throws LdapException
      */
     public function hasDn($dn)
     {
@@ -627,6 +627,10 @@ class LdapConnection implements Selectable, Inspectable
         $this->bind();
 
         $result = ldap_read($ds, $dn, '(objectClass=*)', array('objectClass'));
+        if ($result === false) {
+            return false;
+        }
+
         return ldap_count_entries($ds, $result) > 0;
     }
 
@@ -654,6 +658,10 @@ class LdapConnection implements Selectable, Inspectable
         }
 
         $children = ldap_get_entries($ds, $result);
+        if ($children === false) {
+            return false;
+        }
+
         for ($i = 0; $i < $children['count']; $i++) {
             $result = $this->deleteRecursively($children[$i]['dn']);
             if (! $result) {
@@ -785,6 +793,10 @@ class LdapConnection implements Selectable, Inspectable
         $count = 0;
         $entries = array();
         $entry = ldap_first_entry($ds, $results);
+        if ($entry === false) {
+            return [];
+        }
+
         do {
             if ($unfoldAttribute) {
                 $rows = $this->cleanupAttributes(ldap_get_attributes($ds, $entry), $fields, $unfoldAttribute);
@@ -882,7 +894,19 @@ class LdapConnection implements Selectable, Inspectable
             }
         }
 
+        $controls = [];
         $legacyControlHandling = version_compare(PHP_VERSION, '7.3.0') < 0;
+        if ($serverSorting && $query->hasOrder()) {
+            $control = [
+                'oid'   => LDAP_CONTROL_SORTREQUEST,
+                'value' => $this->encodeSortRules($query->getOrder())
+            ];
+            if ($legacyControlHandling) {
+                ldap_set_option($ds, LDAP_OPT_SERVER_CONTROLS, [$control]);
+            } else {
+                $controls[LDAP_CONTROL_SORTREQUEST] = $control;
+            }
+        }
 
         $count = 0;
         $cookie = '';
@@ -892,15 +916,15 @@ class LdapConnection implements Selectable, Inspectable
                 // Do not request the pagination control as a critical extension, as we want the
                 // server to return results even if the paged search request cannot be satisfied
                 ldap_control_paged_result($ds, $pageSize, false, $cookie);
-            }
-
-            if ($serverSorting && $query->hasOrder()) {
-                ldap_set_option($ds, LDAP_OPT_SERVER_CONTROLS, array(
-                    array(
-                        'oid'   => LdapCapabilities::LDAP_SERVER_SORT_OID,
-                        'value' => $this->encodeSortRules($query->getOrder())
-                    )
-                ));
+            } else {
+                $controls[LDAP_CONTROL_PAGEDRESULTS] = [
+                    'oid'        => LDAP_CONTROL_PAGEDRESULTS,
+                    'iscritical' => false, // See above
+                    'value'      => [
+                        'size'   => $pageSize,
+                        'cookie' => $cookie
+                    ]
+                ];
             }
 
             $results = $this->ldapSearch(
@@ -910,7 +934,7 @@ class LdapConnection implements Selectable, Inspectable
                 ($serverSorting || ! $query->hasOrder()) && $limit ? $offset + $limit : 0,
                 0,
                 LDAP_DEREF_NEVER,
-                $legacyControlHandling ? null : $pageSize
+                empty($controls) ? null : $controls
             );
             if ($results === false) {
                 if (ldap_errno($ds) === self::LDAP_NO_SUCH_OBJECT) {
@@ -940,6 +964,10 @@ class LdapConnection implements Selectable, Inspectable
             }
 
             $entry = ldap_first_entry($ds, $results);
+            if ($entry === false) {
+                return [];
+            }
+
             do {
                 if ($unfoldAttribute) {
                     $rows = $this->cleanupAttributes(ldap_get_attributes($ds, $entry), $fields, $unfoldAttribute);
@@ -976,17 +1004,24 @@ class LdapConnection implements Selectable, Inspectable
                 && ($entry = ldap_next_entry($ds, $entry))
             );
 
-            if ($legacyControlHandling && false === @ldap_control_paged_result_response($ds, $results, $cookie)) {
-                // If the page size is greater than or equal to the sizeLimit value, the server should ignore the
-                // control as the request can be satisfied in a single page: https://www.ietf.org/rfc/rfc2696.txt
-                // This applies no matter whether paged search requests are permitted or not. You're done once you
-                // got everything you were out for.
-                if ($serverSorting && count($entries) !== $limit) {
-                    // The server does not support pagination, but still returned a response by ignoring the
-                    // pagedResultsControl. We output a warning to indicate that the pagination control was ignored.
-                    Logger::warning(
-                        'Unable to request paged LDAP results. Does the server allow paged search requests?'
-                    );
+            if ($legacyControlHandling) {
+                if (false === @ldap_control_paged_result_response($ds, $results, $cookie)) {
+                    // If the page size is greater than or equal to the sizeLimit value, the server should ignore the
+                    // control as the request can be satisfied in a single page: https://www.ietf.org/rfc/rfc2696.txt
+                    // This applies no matter whether paged search requests are permitted or not. You're done once you
+                    // got everything you were out for.
+                    if ($serverSorting && count($entries) !== $limit) {
+                        // The server does not support pagination, but still returned a response by ignoring the
+                        // pagedResultsControl. We output a warning to indicate that the pagination control was ignored.
+                        Logger::warning(
+                            'Unable to request paged LDAP results. Does the server allow paged search requests?'
+                        );
+                    }
+                }
+            } else {
+                ldap_parse_result($ds, $results, $errno, $dn, $errmsg, $refs, $controlsReturned);
+                if (isset($controlsReturned[LDAP_CONTROL_PAGEDRESULTS])) {
+                    $cookie = $controlsReturned[LDAP_CONTROL_PAGEDRESULTS]['value']['cookie'];
                 }
             }
 
@@ -1167,9 +1202,7 @@ class LdapConnection implements Selectable, Inspectable
     /**
      * Prepare and establish a connection with the LDAP server
      *
-     * @param   Inspection  $info   Optional inspection to fill with diagnostic info
-     *
-     * @return  resource            A LDAP link identifier
+     * @param   ?Inspection  $info   Optional inspection to fill with diagnostic info
      *
      * @throws  LdapException       In case the connection is not possible
      */
@@ -1181,7 +1214,10 @@ class LdapConnection implements Selectable, Inspectable
 
         $hostname = $this->normalizeHostname($this->hostname);
 
-        $ds = ldap_connect($hostname, $this->port);
+        $ds = ldap_connect($hostname);
+        if ($ds === false) {
+            throw new LdapException('Failed to connect to LDAP');
+        }
 
         // Set a proper timeout for each connection
         ldap_set_option($ds, LDAP_OPT_NETWORK_TIMEOUT, $this->timeout);
@@ -1211,7 +1247,7 @@ class LdapConnection implements Selectable, Inspectable
     }
 
     /**
-     * Perform a LDAP search and return the result
+     * Perform a LDAP search and return the result or false on error
      *
      * @param   LdapQuery   $query
      * @param   array       $attributes     An array of the required attributes
@@ -1219,9 +1255,7 @@ class LdapConnection implements Selectable, Inspectable
      * @param   int         $sizelimit      Enables you to limit the count of entries fetched
      * @param   int         $timelimit      Sets the number of seconds how long is spend on the search
      * @param   int         $deref
-     * @param   int         $pageSize       The page size to request (Only supported with PHP v7.3+)
-     *
-     * @return  resource|bool               A search result identifier or false on error
+     * @param   array       $controls       LDAP Controls to send with the request (Only supported with PHP v7.3+)
      *
      * @throws  LogicException              If the LDAP query search scope is unsupported
      */
@@ -1232,7 +1266,7 @@ class LdapConnection implements Selectable, Inspectable
         $sizelimit = 0,
         $timelimit = 0,
         $deref = LDAP_DEREF_NEVER,
-        $pageSize = null
+        $controls = null
     ) {
         $queryString = (string) $query;
         $baseDn = $query->getBase() ?: $this->getDn();
@@ -1287,18 +1321,11 @@ class LdapConnection implements Selectable, Inspectable
                 throw new LogicException('LDAP scope %s not supported by ldapSearch', $scope);
         }
 
-        if ($pageSize !== null) {
-            $serverctrls[] = [
-                'oid' => LDAP_CONTROL_PAGEDRESULTS,
-                // Do not request the pagination control as a critical extension, as we want the
-                // server to return results even if the paged search request cannot be satisfied
-                'iscritical' => false,
-                'value' => [
-                    'size' => $pageSize,
-                    'cookie' => ''
-                ]
-            ];
-
+        // Explicit calls with and without controls,
+        // because the parameter is only supported since PHP 7.3.
+        // Since it is a public method,
+        // providing controls will naturally fail if the parameter is not supported by PHP.
+        if ($controls !== null) {
             return @$function(
                 $this->getConnection(),
                 $baseDn,
@@ -1308,7 +1335,7 @@ class LdapConnection implements Selectable, Inspectable
                 $sizelimit,
                 $timelimit,
                 $deref,
-                $serverctrls
+                $controls
             );
         } else {
             return @$function(
@@ -1543,6 +1570,13 @@ class LdapConnection implements Selectable, Inspectable
         return $insp;
     }
 
+    /**
+     * Normalize all given hostnames to a valid LDAP URL
+     *
+     * @param string $hostname
+     *
+     * @return string
+     */
     protected function normalizeHostname($hostname)
     {
         $scheme = $this->encryption === static::LDAPS ? 'ldaps://' : 'ldap://';
