@@ -3,9 +3,9 @@
 
 namespace Icinga\Web\Widget\Dashboard;
 
+use Icinga\Web\Session;
 use Icinga\Web\Url;
 use Icinga\Data\ConfigObject;
-use Icinga\Exception\IcingaException;
 
 /**
  * A dashboard pane dashlet
@@ -22,6 +22,8 @@ class Dashlet extends UserWidget
      */
     private $url;
 
+    private $name;
+
     /**
      * The title being displayed on top of the dashlet
      * @var
@@ -55,17 +57,15 @@ class Dashlet extends UserWidget
      */
     private $template =<<<'EOD'
 
-    <div class="container" data-icinga-url="{URL}">
-        <h1><a href="{FULL_URL}" aria-label="{TOOLTIP}" title="{TOOLTIP}" data-base-target="col1">{TITLE}</a></h1>
+    <div class="container" data-icinga-url="{URL}" data-url-hash="{URL_HASH}">
+        <h1><a
+            href="{FULL_URL}"
+            aria-label="{TOOLTIP}"
+            title="{TOOLTIP}"
+            data-url-hash="{FULL_URL_HASH}"
+            data-base-target="col1"
+        >{TITLE}</a></h1>
         <p class="progress-label">{PROGRESS_LABEL}<span>.</span><span>.</span><span>.</span></p>
-        <noscript>
-            <iframe
-                src="{IFRAME_URL}"
-                style="height:100%; width:99%"
-                frameborder="no"
-                title="{TITLE_PREFIX}{TITLE}">
-            </iframe>
-        </noscript>
     </div>
 EOD;
 
@@ -91,11 +91,23 @@ EOD;
      */
     public function __construct($title, $url, Pane $pane)
     {
+        $this->name = $title;
         $this->title = $title;
         $this->pane = $pane;
         $this->url = $url;
     }
 
+    public function setName($name)
+    {
+        $this->name = $name;
+        return $this;
+    }
+
+    public function getName()
+    {
+        return $this->name;
+    }
+
     /**
      * Retrieve the dashlets title
      *
@@ -234,14 +246,23 @@ EOD;
         }
 
         $url = $this->getUrl();
-        $url->setParam('view', 'compact');
-        $iframeUrl = clone $url;
-        $iframeUrl->setParam('isIframe');
+        $url->setParam('showCompact', true);
+        $fullUrl = $url->getUrlWithout(['showCompact', 'limit', 'view']);
+
+        $urlHash = '';
+        $fullUrlHash = '';
+        if ($url->getPath() === 'iframe') {
+            $urlHash = hash('sha256', Url::fromPath($url->getParam('url'))->getAbsoluteUrl()
+                . Session::getSession()->getId());
+            $fullUrlHash = hash('sha256', Url::fromPath($fullUrl->getParam('url'))->getAbsoluteUrl()
+                . Session::getSession()->getId());
+        }
 
         $searchTokens = array(
             '{URL}',
-            '{IFRAME_URL}',
+            '{URL_HASH}',
             '{FULL_URL}',
+            '{FULL_URL_HASH}',
             '{TOOLTIP}',
             '{TITLE}',
             '{TITLE_PREFIX}',
@@ -250,8 +271,9 @@ EOD;
 
         $replaceTokens = array(
             $url,
-            $iframeUrl,
-            $url->getUrlWithout(array('view', 'limit')),
+            $urlHash,
+            $fullUrl,
+            $fullUrlHash,
             sprintf($view->translate('Show %s', 'dashboard.dashlet.tooltip'), $view->escape($this->getTitle())),
             $view->escape($this->getTitle()),
             $view->translate('Dashlet') . ': ',
