@@ -3,6 +3,7 @@
 
 namespace Icinga\Module\Monitoring\Backend\Ido\Query;
 
+use Icinga\Data\Filter\FilterExpression;
 use Zend_Db_Select;
 use Icinga\Data\Filter\Filter;
 
@@ -59,12 +60,12 @@ class EventhistoryQuery extends IdoQuery
             'service_display_name'
         );
         $this->subQueries = array(
+            $this->createSubQuery('Notificationhistory', $columns),
             $this->createSubQuery('Statehistory', $columns),
             $this->createSubQuery('Downtimestarthistory', $columns),
             $this->createSubQuery('Downtimeendhistory', $columns),
             $this->createSubQuery('Commenthistory', $columns),
             $this->createSubQuery('Commentdeletionhistory', $columns),
-            $this->createSubQuery('Notificationhistory', $columns),
             $this->createSubQuery('Flappingstarthistory', $columns),
             $this->createSubQuery('Flappingendhistory', $columns)
         );
@@ -120,4 +121,14 @@ class EventhistoryQuery extends IdoQuery
         }
         return $this;
     }
+
+    public function whereEx(FilterExpression $ex)
+    {
+        $this->requireColumn($ex->getColumn());
+        foreach ($this->subQueries as $sub) {
+            $sub->whereEx($ex);
+        }
+
+        return $this;
+    }
 }
