@@ -3,6 +3,9 @@
 
 namespace Icinga\Module\Monitoring\Backend\Ido\Query;
 
+use Icinga\Data\Filter\Filter;
+use Icinga\Data\Filter\FilterExpression;
+
 /**
  * Query for host state history records
  */
@@ -78,21 +81,31 @@ class HoststatehistoryQuery extends IdoQuery
         ),
     );
 
-    /**
-     * {@inheritdoc}
-     */
-    public function whereToSql($col, $sign, $expression)
+    protected function requireFilterColumns(Filter $filter)
     {
-        if ($col === 'UNIX_TIMESTAMP(hh.state_time)') {
-            return 'hh.state_time ' . $sign . ' ' . $this->timestampForSql($this->valueToTimestamp($expression));
-        } elseif ($col === $this->columnMap['statehistory']['type']
-            && ! is_array($expression)
-            && array_key_exists($expression, $this->types)
-        ) {
-            return 'hh.state_type ' . $sign . ' ' . $this->types[$expression];
-        } else {
-            return parent::whereToSql($col, $sign, $expression);
+        if ($filter instanceof FilterExpression) {
+            switch ($filter->getColumn()) {
+                case 'timestamp':
+                    $this->requireColumn('timestamp');
+                    $filter->setColumn('hh.state_time');
+                    $filter->setExpression($this->timestampForSql($this->valueToTimestamp($filter->getExpression())));
+                    return null;
+                case 'type':
+                    if (! is_array($filter->getExpression())) {
+                        $this->requireColumn('type');
+                        $filter->setColumn('hh.state_type');
+                        if (isset($this->types[$filter->getExpression()])) {
+                            $filter->setExpression($this->types[$filter->getExpression()]);
+                        } else {
+                            $filter->setExpression(-1);
+                        }
+
+                        return null;
+                    }
+            }
         }
+
+        return parent::requireFilterColumns($filter);
     }
 
     /**
