@@ -202,10 +202,10 @@ class ServicestatusQuery extends IdoQuery
             'service_last_notification'                 => 'UNIX_TIMESTAMP(ss.last_notification)',
             'service_last_state_change'                 => 'UNIX_TIMESTAMP(ss.last_state_change)',
             'service_last_state_change_ts'              => 'ss.last_state_change',
-            'service_last_time_critical'                => 'ss.last_time_critical',
-            'service_last_time_ok'                      => 'ss.last_time_ok',
-            'service_last_time_unknown'                 => 'ss.last_time_unknown',
-            'service_last_time_warning'                 => 'ss.last_time_warning',
+            'service_last_time_critical'                => 'UNIX_TIMESTAMP(ss.last_time_critical)',
+            'service_last_time_ok'                      => 'UNIX_TIMESTAMP(ss.last_time_ok)',
+            'service_last_time_unknown'                 => 'UNIX_TIMESTAMP(ss.last_time_unknown)',
+            'service_last_time_warning'                 => 'UNIX_TIMESTAMP(ss.last_time_warning)',
             'service_long_output'                       => 'ss.long_output',
             'service_max_check_attempts'                => 'ss.max_check_attempts',
             'service_modified_service_attributes'       => 'ss.modified_service_attributes',
