@@ -10,6 +10,8 @@ use Icinga\Module\Monitoring\Command\IcingaCommand;
  */
 class DeleteCommentCommand extends IcingaCommand
 {
+    use CommandAuthor;
+
     /**
      * ID of the comment that is to be deleted
      *
@@ -17,6 +19,15 @@ class DeleteCommentCommand extends IcingaCommand
      */
     protected $commentId;
 
+    /**
+     * Name of the comment (Icinga 2.4+)
+     *
+     * Required for removing the comment via Icinga 2's API.
+     *
+     * @var string
+     */
+    protected $commentName;
+
     /**
      * Whether the command affects a service comment
      *
@@ -47,6 +58,33 @@ class DeleteCommentCommand extends IcingaCommand
         return $this;
     }
 
+    /**
+     * Get the name of the comment (Icinga 2.4+)
+     *
+     * Required for removing the comment via Icinga 2's API.
+     *
+     * @return string
+     */
+    public function getCommentName()
+    {
+        return $this->commentName;
+    }
+
+    /**
+     * Set the name of the comment (Icinga 2.4+)
+     *
+     * Required for removing the comment via Icinga 2's API.
+     *
+     * @param   string  $commentName
+     *
+     * @return  $this
+     */
+    public function setCommentName($commentName)
+    {
+        $this->commentName = $commentName;
+        return $this;
+    }
+
     /**
      * Get whether the command affects a service comment
      *
