@@ -129,26 +129,32 @@ class DbResourcePage extends Form
             $connectionError = $e;
         }
 
-        if ($connectionError === null && array_search('icinga_instances', $db->listTables(), true) !== false) {
+        if ($connectionError === null
+            && (
+                in_array('icinga_instances', $db->listTables(), true)
+                || in_array('icingadb_instance', $db->listTables(), true)
+            )
+        ) {
             $this->warning($this->translate(
-                'The database you\'ve configured to use for Icinga Web 2 seems to be the one of Icinga. Please be aware'
-                . ' that this database configuration is supposed to be used for Icinga Web 2\'s configuration and that'
-                . ' it is highly recommended to not mix different schemas in the same database. If this is intentional,'
-                . ' you can skip the validation and ignore this warning. If not, please provide a different database.'
+                'The database you\'ve configured to use for Icinga Web seems to be the one of Icinga 2'
+                . ' / Icinga DB. Please be aware that this database configuration is supposed to be used for'
+                . ' Icinga Web\'s configuration and that it is highly recommended to not mix different schemas'
+                . ' in the same database. If this is intentional, you can skip the validation and ignore this'
+                . ' warning. If not, please provide a different database.'
             ));
             $state = false;
         }
 
         if ($this->getValue('db') === 'pgsql') {
             if ($connectionError !== null) {
-                $this->warning(sprintf(
-                    $this->translate('Unable to check the server\'s version. This is usually not a critical error'
-                    . ' as there is probably only access to the database permitted which does not exist yet. If you are'
-                    . ' absolutely sure you are running PostgreSQL in a version equal to or newer than 9.1,'
-                    . ' you can skip the validation and safely proceed to the next step. The error was: %s'),
-                    $connectionError->getMessage()
-                ));
-                $state = false;
+//              $this->warning(sprintf(
+//                  $this->translate('Unable to check the server\'s version. This is usually not a critical error'
+//                  . ' as there is probably only access to the database permitted which does not exist yet. If you are'
+//                  . ' absolutely sure you are running PostgreSQL in a version equal to or newer than 9.1,'
+//                  . ' you can skip the validation and safely proceed to the next step. The error was: %s'),
+//                  $connectionError->getMessage()
+//              ));
+//              $state = false;
             } else {
                 $version = $db->getServerVersion();
                 if (version_compare($version, '9.1', '<')) {
