@@ -7,6 +7,8 @@ use RecursiveIteratorIterator;
 
 class RequirementsRenderer extends RecursiveIteratorIterator
 {
+    protected $tags;
+
     public function beginIteration(): void
     {
         $this->tags[] = '<ul class="requirements">';
@@ -20,6 +22,7 @@ class RequirementsRenderer extends RecursiveIteratorIterator
     public function beginChildren(): void
     {
         $this->tags[] = '<li>';
+        /** @var RequirementSet $currentSet */
         $currentSet = $this->getSubIterator();
         $state = $currentSet->getState() ? 'fulfilled' : ($currentSet->isOptional() ? 'not-available' : 'missing');
         $this->tags[] = '<ul class="set-state ' . $state . '">';
