@@ -348,8 +348,8 @@
          */
         this.loading = false;
 
-        this.on('rendered', '#main > .container', this.onRendered, this);
-        this.on('beforerender', '#main > .container', this.beforeRender, this);
+        this.on('rendered', '#main .container', this.onRendered, this);
+        this.on('beforerender', '#main .container', this.beforeRender, this);
         this.on('click', 'table.action tr[href], table.table-row-selectable tr[href]', this.onRowClicked, this);
     };
     ActionTable.prototype = new Icinga.EventListener();
@@ -416,6 +416,7 @@
         } else {
             if (_this.icinga.loader.getLinkTargetFor($tr).attr('id') === 'col2') {
                 _this.icinga.ui.layout1col();
+                _this.icinga.history.pushCurrentState();
             }
         }
 
@@ -437,7 +438,7 @@
         var _this = evt.data.self;
 
         if (evt.currentTarget !== container) {
-            // Nested containers are ignored
+            // Nested containers are not processed multiple times
             return;
         }
 
@@ -448,7 +449,6 @@
             // the highest precedence before hrefs defined in the tr itself and regular links
             var $a = $('a[href].rowaction', el).first();
             if ($a.length) {
-                // TODO: Find out whether we leak memory on IE with this:
                 $(el).attr('href', $a.attr('href'));
                 return;
             }
@@ -461,11 +461,6 @@
             }
         });
 
-        // IE will not ignore user-select unless we cancel selectstart
-        $('table.action.multiselect tr, table.table-row-selectable.multiselect tr', container).each(function(idx, el) {
-            $(el).on('selectstart', false);
-        });
-
         // draw all active selections that have disappeared on reload
         _this.tables().each(function(i, el) {
             new Selection(el, _this.icinga).refresh();
@@ -481,7 +476,7 @@
         var _this = evt.data.self;
 
         if (evt.currentTarget !== container) {
-            // Nested containers are ignored
+            // Nested containers are not processed multiple times
             return;
         }
 
